@@ -1,12 +1,12 @@
-use clap::{App, Arg};
+use clap::{crate_version, App, Arg};
 use dns_lookup::lookup_host;
-use mb_dev::{shell_exec, VERSION};
+use mb_dev::shell_exec;
 
 fn main() {
     let matches = App::new("dkh")
         .about("Delete hosts from ~/.ssh/known_hosts")
+        .version(crate_version!())
         .arg(Arg::new("hosts").multiple(true).required(true))
-        .version(VERSION)
         .get_matches();
 
     for host in matches.values_of("hosts").unwrap().collect::<Vec<_>>() {
